import { defineStore } from 'pinia';

interface CartItem {
  addID: string;
  addTime: string;
  name: string;
  price: number;
  quantity: number;
  image: string;
  selected?: boolean;
}

export const useCartStore = defineStore({
  id: 'cart',
  state: () => ({
    cartItems: [] as CartItem[]
  }),

  getters: {
    // 获取购物车商品总数
    cartItemCount: (state) => state.cartItems.length,
    
    // 获取购物车商品总价
    cartTotalPrice: (state) => {
      return state.cartItems.reduce((total, item) => {
        return total + (item.price * item.quantity);
      }, 0);
    }
  },

  actions: {
    // 设置购物车商品
    setCartItems(items: CartItem[]) {
      this.cartItems = items;
    },

    // 添加商品到购物车
    addToCart(item: CartItem) {
      // 检查是否已存在相同商品
      const existingItem = this.cartItems.find(cartItem => cartItem.addID === item.addID);
      if (existingItem) {
        // 如果存在，增加数量
        existingItem.quantity += item.quantity;
      } else {
        // 如果不存在，添加新商品
        this.cartItems.push(item);
      }
    },

    // 从购物车移除商品
    removeFromCart(addID: string) {
      this.cartItems = this.cartItems.filter(item => item.addID !== addID);
    },

    // 清空购物车
    clearCart() {
      this.cartItems = [];
    },

    // 更新商品数量
    updateItemQuantity(addID: string, quantity: number) {
      const item = this.cartItems.find(item => item.addID === addID);
      if (item) {
        item.quantity = quantity;
      }
    },

    // 更新商品选中状态
    updateItemSelected(addID: string, selected: boolean) {
      const item = this.cartItems.find(item => item.addID === addID);
      if (item) {
        item.selected = selected;
      }
    },

    // 全选/取消全选
    updateAllSelected(selected: boolean) {
      this.cartItems.forEach(item => {
        item.selected = selected;
      });
    }
  },

  persist: true
}); 